@@ -8,9 +8,9 @@ Router::Statistics::OID - OID Module for Router::Statistics
 
 =head1 VERSION
 
-Version 1.35
+Version 1.45
 
-our $VERSION = '1.35';
+our $VERSION = '1.45';
 
 =head1 SYNOPSIS
 
@@ -24,6 +24,7 @@ These functions are used internally to Router::Statistics however may become mor
 
 telnet_commands
 CPE_populate_oid
+CPE_DOCSIS_populate_oid ( currently CPE_populate_oid wraps this for backward compatibility )
 Router_Link_Map_oid
 Router_inventory_oid
 Router_interface_oid
@@ -62,9 +63,16 @@ return \%telnet_command_set;
 
 sub CPE_populate_oid
 {
+return CPE_DOCSIS_populate_oid();
+}
+
+sub CPE_DOCSIS_populate_oid
+{
 my %snmp_usable_oid =
 			(
 		'sysDescr'			=>	'1.3.6.1.2.1.1.1.0',
+		'sysUpTime'                     =>      '1.3.6.1.2.1.1.3.0',
+		'sysORDescr'			=>	'1.3.6.1.2.1.1.9.0',
 		'docsDevSwCurrentVers'		=>	'1.3.6.1.2.1.69.1.3.5.0',
 		'ifPhysAddress'			=>	'1.3.6.1.2.1.2.2.1.6.1',
 		'DownStreamFrequency'		=>	'1.3.6.1.2.1.10.127.1.1.1.1.2.3',
@@ -85,8 +93,13 @@ my %snmp_usable_oid =
 		'docsIfSigQExtUnerroreds'	=>	'1.3.6.1.2.1.10.127.1.1.4.1.8.3',
 		'docsIfSigQExtCorrecteds'	=>	'1.3.6.1.2.1.10.127.1.1.4.1.9.3',
 		'docsIfSigQExtUncorrectables'	=>	'1.3.6.1.2.1.10.127.1.1.4.1.10.3',
+		'docsIfCmCapabilities'		=>	'1.3.6.1.2.1.10.127.1.2.1.1.2.0',
 		'docsIfCmCapabilities1'		=>	'1.3.6.1.2.1.10.127.1.2.1.1.2.1',
-		'docsIfCmCapabilities2'		=>	'1.3.6.1.2.1.10.127.1.2.1.1.2.2'
+		'docsIfCmCapabilities2'		=>	'1.3.6.1.2.1.10.127.1.2.1.1.2.2',
+		'docsDevSwFilename'		=>	'1.3.6.1.2.1.69.1.3.2.0',
+		'docsDevSwServer'		=>	'1.3.6.1.2.1.69.1.3.1.0',
+		'docsDevSwAdminStatus'		=>	'1.3.6.1.2.1.69.1.3.3.0',
+		'docsDevResetNow'		=>	'1.3.6.1.2.1.69.1.1.3.0'
 			);
 return \%snmp_usable_oid;
 }
@@ -170,10 +183,33 @@ my %snmp_usable_oid =
 return \%snmp_usable_oid;
 }
 
+sub ntp_populate_oid
+{
+my %snmp_ntp_oid =
+	(
+	'cntpSysClock'			=>	'1.3.6.1.4.1.9.9.168.1.1.10.0'
+	);
+return \%snmp_ntp_oid;
+}
+
 sub STM_populate_oid
 {
 my %snmp_stm_oid =
         (
+	'PRIVATE_stm_rule_base'		=>	'1.3.6.1.4.1.9.9.341.1.1.1',
+	'PRIVATE_cqmCmtsEnfRuleName'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1',
+	'ccqmCmtsEnfRuleRegQoS'		=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.2',
+	'ccqmCmtsEnfRuleEnfQos'		=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.3',
+	'ccqmCmtsEnfRuleMonDuration'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.4',
+	'ccqmCmtsEnfRuleSampleRate'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.5',
+	'ccqmCmtsEnfRulePenaltyPeriod'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.6',
+	'ccqmCmtsEnfRuleByteCount'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.7',
+	'ccqmCmtsEnfRuleDirection'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.8',
+	'ccqmCmtsEnfRuleAutoEnforce'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.9',
+	'ccqmCmtsEnfRuleRowStatus'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.10',
+	'ccqmCmtsEnfRuleStartTime'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.16',
+	'ccqmCmtsEnfRuleDuration'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.17',
+	'ccqmCmtsEnfRuleAverage'	=>	'1.3.6.1.4.1.9.9.341.1.1.1.1.18',
         'PRIVATE_stm_base'              =>      '1.3.6.1.4.1.9.9.341.1.2.2',
         'ccqmEnfRuleViolateID'          =>      '1.3.6.1.4.1.9.9.341.1.2.2.1.1',
         'ccqmEnfRuleViolateMacAddr'     =>      '1.3.6.1.4.1.9.9.341.1.2.2.1.2',
@@ -185,6 +221,45 @@ my %snmp_stm_oid =
 return \%snmp_stm_oid;
 }
 
+sub DOCSIS_Modulation
+{
+my %profile_info = (
+        'PRIVATE_docsIfCmtsMod_base'            =>      '.1.3.6.1.2.1.10.127.1.3.5.1',
+        'docsIfCmtsModIndex'                    =>      '.1.3.6.1.2.1.10.127.1.3.5.1.1',
+        'docsIfCmtsModIntervalUsageCode'        =>      '.1.3.6.1.2.1.10.127.1.3.5.1.2',
+        'docsIfCmtsModControl'                  =>      '.1.3.6.1.2.1.10.127.1.3.5.1.3',
+        'docsIfCmtsModType'                     =>      '.1.3.6.1.2.1.10.127.1.3.5.1.4',
+        'docsIfCmtsModPreambleLen'              =>      '.1.3.6.1.2.1.10.127.1.3.5.1.5',
+        'docsIfCmtsModDifferentialEncoding'     =>      '.1.3.6.1.2.1.10.127.1.3.5.1.6',
+        'docsIfCmtsModFECErrorCorrection'       =>      '.1.3.6.1.2.1.10.127.1.3.5.1.7',
+        'docsIfCmtsModFECCodewordLength'        =>      '.1.3.6.1.2.1.10.127.1.3.5.1.8',
+        'docsIfCmtsModScramblerSeed'            =>      '.1.3.6.1.2.1.10.127.1.3.5.1.9',
+        'docsIfCmtsModMaxBurstSize'             =>      '.1.3.6.1.2.1.10.127.1.3.5.1.10',
+        'docsIfCmtsModGuardTimeSize'            =>      '.1.3.6.1.2.1.10.127.1.3.5.1.11',
+        'docsIfCmtsModLastCodewordShortened'    =>      '.1.3.6.1.2.1.10.127.1.3.5.1.12',
+        'docsIfCmtsModScrambler'                =>      '.1.3.6.1.2.1.10.127.1.3.5.1.13',
+        'docsIfCmtsModByteInterleaverDepth'     =>      '.1.3.6.1.2.1.10.127.1.3.5.1.14',
+        'docsIfCmtsModByteInterleaverBlockSize' =>      '.1.3.6.1.2.1.10.127.1.3.5.1.15',
+        'docsIfCmtsModPreambleType'             =>      '.1.3.6.1.2.1.10.127.1.3.5.1.16',
+        'docsIfCmtsModTcmErrorCorrectionOn'     =>      '.1.3.6.1.2.1.10.127.1.3.5.1.17',
+        'docsIfCmtsModScdmaInterleaverStepSize' =>      '.1.3.6.1.2.1.10.127.1.3.5.1.18',
+        'docsIfCmtsModScdmaSpreaderEnable'      =>      '.1.3.6.1.2.1.10.127.1.3.5.1.19',
+        'docsIfCmtsModScdmaSubframeCodes'       =>      '.1.3.6.1.2.1.10.127.1.3.5.1.20',
+        'docsIfCmtsModChannelType'              =>      '.1.3.6.1.2.1.10.127.1.3.5.1.21' );
+return \%profile_info;
+}
+
+sub DOCSIS_packet_cable
+{
+# this is temp name for DOCSIS3/Wideband/Service flow environments
+my %snmp_usable_oid=
+	(
+	'docsIfCmtsCmStatusMacAddress'		=>	'1.3.6.1.2.1.10.127.1.3.3.1.2',
+	'docsIfCmtsMacToCmEntry'		=>	'1.3.6.1.2.1.10.127.1.3.7.1.2'
+	);
+return \%snmp_usable_oid;
+}
+	
 
 sub DOCSIS_populate_oid
 {
@@ -326,7 +401,7 @@ L<http://search.cpan.org/dist/Router-Statistics>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2006 Andrew S. Kennedy, all rights reserved.
+Copyright 2007 Andrew S. Kennedy, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
